==> org-lsst-ccs-subsystem-refrig-main-4.2.0-sources.jar: org/lsst/ccs/subsystem/refrig/ColdCompressor.java <==
package org.lsst.ccs.subsystem.refrig;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;
import org.lsst.ccs.bus.data.Alert;
import org.lsst.ccs.command.annotations.Argument;
import org.lsst.ccs.command.annotations.Command;
import org.lsst.ccs.commons.annotations.LookupField;
import org.lsst.ccs.commons.annotations.LookupName;
import org.lsst.ccs.framework.ClearAlertHandler.ClearAlertCode;
import org.lsst.ccs.subsystem.common.ErrorUtils;
import org.lsst.ccs.subsystem.refrig.constants.ColdCompValves;
import org.lsst.ccs.subsystem.refrig.constants.VfdState;
import org.lsst.ccs.subsystem.refrig.data.ColdCompState;
import org.lsst.ccs.subsystem.refrig.data.RefrigException;

/**
 *  Controls a refrigeration cold compressor.
 *
 *  @author Owen Saxton
 */
public class ColdCompressor extends Compressor {

    private static final int[] maqChannels = new int[ColdCompValves.NUM_VALVES];
    static {
        maqChannels[ColdCompValves.VALVE_BYPASS] = CompMaq20Device.CHAN_BYPASS_VALVE;
        maqChannels[ColdCompValves.VALVE_COOLANT] = CompMaq20Device.CHAN_COOLANT_VALVE;
        maqChannels[ColdCompValves.VALVE_EEPR] = CompMaq20Device.CHAN_EEPR_VALVE;
    }
    
    @LookupName
    private String name;
    @LookupField(strategy = LookupField.Strategy.CHILDREN)
    private A1000Device vfdDevc;

    private static final Logger LOG = Logger.getLogger(ColdCompressor.class.getName());
    private final ColdCompState coldState;


    /**
     *  Constructor.
     */
    public ColdCompressor() {
        super(new ColdCompState());
        coldState = (ColdCompState)getState();
    }
            

    /**
     *  Initializes the cold compressor control.
     */
    @Override
    public void postInit()
    {
        if (vfdDevc == null) {
            ErrorUtils.reportConfigError(LOG, name, "vfdDevc", "not specified");
        }
        super.postInit();
    }


    /**
     *  Command to get the valid valve names.
     *
     *  @return  The index value
     */
    @Command(type=Command.CommandType.QUERY, description="Get the valid valve names", level=0)
    public List<String> getValveNames()
    {
        List<String> names = new ArrayList<>();
        for (String vName : ColdCompValves.NAME_MAP.keySet()) {
            names.add(vName);
        }
        return names;
    }


    /**
     *  Command to set a valve position.
     *
     *  @param  valve  The valve name
     *  @param  posn   The valve position  (0 - 1)
     *  @throws  RefrigException
     */
    @Command(type=Command.CommandType.ACTION, description="Set a cold compressor's valve position")
    public synchronized void setValvePosition(@Argument(description="Valve name") String valve,
                                              @Argument(description="Valve position") double posn) throws RefrigException
    {
        gotCommand = true;
        Integer valveId = ColdCompValves.NAME_MAP.get(valve);
        if (valveId == null) {
            throw new RefrigException("Invalid cold valve name: " + valve);
        }
        maq20Devc.setValvePosition(maqChannels[valveId], posn);
    }


    /**
     *  Command to set the VFD frequency.
     *
     *  @param  freq  The frequency
     *  @throws  RefrigException
     */
     @Command(type=Command.CommandType.ACTION, description="Set a cold compressor's VFD frequency")
    public synchronized void setVfdFrequency(@Argument(description="Frequency") double freq) throws RefrigException
    {
        gotCommand = true;
        vfdDevc.setFrequency(freq);
    }


    /**
     *  Command to reset a VFD fault condition.
     *
     *  @throws  RefrigException
     */
    @Command(type=Command.CommandType.ACTION, description="Reset a cold compressor's VFD fault")
    public synchronized void resetVfdFault() throws RefrigException
    {
        gotCommand = true;
        vfdDevc.resetFault();
    }


    /**
     *  Updates the compressor state.
     *
     *  This should be called at regular (short) intervals to maintain the correct state
     *
     *  @return  Whether any value changed
     */
    @Override
    protected synchronized boolean updateState()
    {
        boolean changed = super.updateState();
        for (int valveId = 0; valveId < ColdCompValves.NUM_VALVES; valveId++) {
            double posn = maq20Devc.getValvePosition(maqChannels[valveId]);
            if (!areEqual(posn, coldState.getValvePosition(valveId))) {
                coldState.setValvePosition(valveId, posn);
                changed = true;
            }
        }
        double freq = vfdDevc.getFrequency();
        if (!areEqual(freq, coldState.getVfdFrequency())) {
            coldState.setVfdFrequency(freq);
            changed = true;
        }
        VfdState vfdState = vfdDevc.getState();
        if (vfdState != coldState.getVfdState()) {
            coldState.setVfdState(vfdState);
            changed = true;
        }
        return changed;
    }


    /**
     *  Enables an alert to be cleared.
     * 
     *  @param  alert  The alert
     *  @return  Action code
     */
    @Override
    public ClearAlertCode canClearAlert(Alert alert)
    {
        ClearAlertCode code = vfdDevc.canClearAlert(alert);
        return code == null ? super.canClearAlert(alert) : code;
    }

}

==> org-lsst-ccs-subsystem-refrig-main-4.2.6-sources.jar: org/lsst/ccs/subsystem/refrig/ColdCompressor.java <==
package org.lsst.ccs.subsystem.refrig;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;
import org.lsst.ccs.bus.data.Alert;
import org.lsst.ccs.command.annotations.Argument;
import org.lsst.ccs.command.annotations.Command;
import org.lsst.ccs.commons.annotations.LookupField;
import org.lsst.ccs.commons.annotations.LookupName;
import org.lsst.ccs.framework.ClearAlertHandler.ClearAlertCode;
import org.lsst.ccs.subsystem.common.ErrorUtils;
import org.lsst.ccs.subsystem.refrig.constants.ColdCompValves;
import org.lsst.ccs.subsystem.refrig.constants.VfdState;
import org.lsst.ccs.subsystem.refrig.data.ColdCompState;
import org.lsst.ccs.subsystem.refrig.data.RefrigException;

/**
 *  Controls a refrigeration cold compressor.
 *
 *  @author Owen Saxton
 */
public class ColdCompressor extends Compressor {

    private static final int[] maqChannels = new int[ColdCompValves.NUM_VALVES];
    static {
        maqChannels[ColdCompValves.VALVE_HGB] = CompMaq20Device.CHAN_HGB_VALVE;
        maqChannels[ColdCompValves.VALVE_COOLANT] = CompMaq20Device.CHAN_COOLANT_VALVE;
        maqChannels[ColdCompValves.VALVE_EEPR] = CompMaq20Device.CHAN_EEPR_VALVE;
    }
    
    @LookupName
    private String name;
    @LookupField(strategy = LookupField.Strategy.CHILDREN)
    private A1000Device vfdDevc;

    private static final Logger LOG = Logger.getLogger(ColdCompressor.class.getName());
    private final ColdCompState coldState;


    /**
     *  Constructor.
     */
    public ColdCompressor() {
        super(new ColdCompState());
        coldState = (ColdCompState)getState();
    }
            

    /**
     *  Initializes the cold compressor control.
     */
    @Override
    public void postInit()
    {
        if (vfdDevc == null) {
            ErrorUtils.reportConfigError(LOG, name, "vfdDevc", "not specified");
        }
        super.postInit();
    }


    /**
     *  Command to get the valid valve names.
     *
     *  @return  The index value
     */
    @Command(type=Command.CommandType.QUERY, description="Get the valid valve names", level=0)
    public List<String> getValveNames()
    {
        List<String> names = new ArrayList<>();
        for (String vName : ColdCompValves.NAME_MAP.keySet()) {
            names.add(vName);
        }
        return names;
    }


    /**
     *  Command to set a valve position.
     *
     *  @param  valve  The valve name
     *  @param  posn   The valve position  (0 - 1)
     *  @throws  RefrigException
     */
    @Command(type=Command.CommandType.ACTION, description="Set a cold compressor's valve position")
    public synchronized void setValvePosition(@Argument(description="Valve name") String valve,
                                              @Argument(description="Valve position") double posn) throws RefrigException
    {
        gotCommand = true;
        Integer valveId = ColdCompValves.NAME_MAP.get(valve);
        if (valveId == null) {
            throw new RefrigException("Invalid cold valve name: " + valve);
        }
        maq20Devc.setValvePosition(maqChannels[valveId], posn);
    }


    /**
     *  Command to set the VFD frequency.
     *
     *  @param  freq  The frequency
     *  @throws  RefrigException
     */
     @Command(type=Command.CommandType.ACTION, description="Set a cold compressor's VFD frequency")
    public synchronized void setVfdFrequency(@Argument(description="Frequency") double freq) throws RefrigException
    {
        gotCommand = true;
        vfdDevc.setFrequency(freq);
    }


    /**
     *  Command to reset a VFD fault condition.
     *
     *  @throws  RefrigException
     */
    @Command(type=Command.CommandType.ACTION, description="Reset a cold compressor's VFD fault")
    public synchronized void resetVfdFault() throws RefrigException
    {
        gotCommand = true;
        vfdDevc.resetFault();
    }


    /**
     *  Updates the compressor state.
     *
     *  This should be called at regular (short) intervals to maintain the correct state
     *
     *  @return  Whether any value changed
     */
    @Override
    protected synchronized boolean updateState()
    {
        boolean changed = super.updateState();
        for (int valveId = 0; valveId < ColdCompValves.NUM_VALVES; valveId++) {
            double posn = maq20Devc.getValvePosition(maqChannels[valveId]);
            if (!areEqual(posn, coldState.getValvePosition(valveId))) {
                coldState.setValvePosition(valveId, posn);
                changed = true;
            }
        }
        double freq = vfdDevc.getFrequency();
        if (!areEqual(freq, coldState.getVfdFrequency())) {
            coldState.setVfdFrequency(freq);
            changed = true;
        }
        VfdState vfdState = vfdDevc.getState();
        if (vfdState != coldState.getVfdState()) {
            coldState.setVfdState(vfdState);
            changed = true;
        }
        return changed;
    }


    /**
     *  Enables an alert to be cleared.
     * 
     *  @param  alert  The alert
     *  @return  Action code
     */
    @Override
    public ClearAlertCode canClearAlert(Alert alert)
    {
        ClearAlertCode code = vfdDevc.canClearAlert(alert);
        return code == null ? super.canClearAlert(alert) : code;
    }

}
